from datetime import datetime
from django.db import models
from response.core.models.user_external import ExternalUser

class IncidentManager(models.Manager):
    def create_incident(self, report, reporter, report_time, summary=None, impact=None, lead=None, severity=None):
        incident = self.create(
            report=report,
            reporter=reporter,
            report_time=report_time,
            start_time=report_time,
            summary=summary,
            impact=impact,
            lead=lead,
            severity=severity,
        )
        return incident


class Incident(models.Model):

    objects = IncidentManager()

    # Reporting info
    report = models.CharField(max_length=200)
    reporter = models.ForeignKey(ExternalUser, related_name='reporter', on_delete=models.PROTECT, blank=False, null=True,)
    report_time = models.DateTimeField()

    start_time = models.DateTimeField(null=False)
    end_time = models.DateTimeField(blank=True, null=True)

    # Additional info
    summary = models.TextField(blank=True, null=True, help_text="What's the high level summary?")
    impact = models.TextField(blank=True, null=True, help_text="What impact is this having?")
    lead = models.ForeignKey(ExternalUser, related_name='lead', on_delete=models.PROTECT, blank=True, null=True, help_text="Who is leading?")


    # Severity
    SEVERITIES = (
        ('1', 'critical'),
        ('2', 'major'),
        ('3', 'minor'),
        ('4', 'trivial'),
    )
    severity = models.CharField(max_length=10, blank=True, null=True, choices=SEVERITIES)

    def __str__(self):
        return self.report

    def duration(self):
        delta = (self.end_time or datetime.now()) - self.start_time

        hours, remainder = divmod(delta.total_seconds(), 3600)
        minutes, seconds = divmod(remainder, 60)

        time_str = ""
        if hours > 0:
            hours = int(hours)
            time_str += f"{hours} hrs " if hours > 1 else f"{hours} hr "

        if minutes > 0:
            minutes = int(minutes)
            time_str += f"{minutes} mins " if minutes > 1 else f"{minutes} min "

        if hours == 0 and minutes == 0:
            seconds = int(seconds)
            time_str += f"{seconds} secs"

        return time_str.strip()

    def is_closed(self):
        return True if self.end_time else False

    def severity_text(self):
        for sev_id, text in self.SEVERITIES:
            if sev_id == self.severity:
                return text
        return None

    def severity_emoji(self):
        if not self.severity:
            return "☁️"

        return {
            "1": "⛈️",
            "2": "🌧️",
            "3": "🌦️",
            "4": "🌤️"
        }[self.severity]

    def status_text(self):
        return 'resolved' if self.is_closed() else 'live'

    def status_emoji(self):
        if self.is_closed():
            return ":droplet:"
        else:
            return ":fire:"


# Used to store external identifiers
class IncidentExtension(models.Model):
    class Meta:
        unique_together = ("incident", "key")

    incident = models.ForeignKey(Incident, on_delete=models.CASCADE)
    key      = models.CharField(max_length=50, blank=False, null=False)
    value    = models.CharField(max_length=100, blank=False, null=False)



from django.conf import settings

from response.core.models import Incident, Action, ExternalUser, GetOrCreateSlackExternalUser
from response.slack.models import CommsChannel
from response.slack.decorators import incident_command, get_help
from response.slack.client import SlackError, reference_to_id
from datetime import datetime

@incident_command(['help'], helptext='Display a list of commands and usage')
def send_help_text(incident: Incident, user_id: str, message: str):
    return True, get_help()


@incident_command(['summary'], helptext='Provide a summary of what\'s going on')
def update_summary(incident: Incident, user_id: str, message: str):
    incident.summary = message
    incident.save()
    return True, None


@incident_command(['impact'], helptext='Explain the impact of this')
def update_impact(incident: Incident, user_id: str, message: str):
    incident.impact = message
    incident.save()
    return True, None


@incident_command(['lead'], helptext='Assign someone as the incident lead')
def set_incident_lead(incident: Incident, user_id: str, message: str):
    assignee = reference_to_id(message) or user_id
    name = settings.SLACK_CLIENT.get_user_profile(assignee)['name']
    user = GetOrCreateSlackExternalUser(external_id=assignee, display_name=name)
    incident.lead = user
    incident.save()
    return True, None


@incident_command(['severity', 'sev'], helptext='Set the incident severity')
def set_severity(incident: Incident, user_id: str, message: str):
    for sev_id, sev_name in Incident.SEVERITIES:
        # look for sev name (e.g. critical) or sev id (1)
        if (sev_name in message) or (sev_id in message):
            incident.severity = sev_id
            incident.save()
            return True, None

    return False, None


@incident_command(['rename'], helptext='Rename the incident channel')
def rename_incident(incident: Incident, user_id: str, message: str):
    try:
        comms_channel = CommsChannel.objects.get(incident=incident)
        comms_channel.rename(message)
    except SlackError:
        return True, "👋 Sorry, the channel couldn't be renamed. Make sure that name isn't taken already."
    return True, None


@incident_command(['duration'], helptext='How long has this incident been running?')
def set_severity(incident: Incident, user_id: str, message: str):
    duration = incident.duration()

    comms_channel = CommsChannel.objects.get(incident=incident)
    comms_channel.post_in_channel(f"The incident has been running for {duration}")

    return True, None


@incident_command(['close'], helptext='Close this incident.')
def close_incident(incident: Incident, user_id: str, message: str):
    comms_channel = CommsChannel.objects.get(incident=incident)

    if incident.is_closed():
        comms_channel.post_in_channel(f"This incident was already closed at {incident.end_time.strftime('%Y-%m-%d %H:%M:%S')}")
        return True, None

    incident.end_time = datetime.now()
    incident.save()

    comms_channel.post_in_channel(f"This incident has been closed! 📖 -> 📕")

    return True, None


@incident_command(['action'], helptext='Log a follow up action')
def set_action(incident: Incident, user_id: str, message: str):
    comms_channel = CommsChannel.objects.get(incident=incident)
    name = settings.SLACK_CLIENT.get_user_profile(user_id)['name']
    action_reporter = GetOrCreateSlackExternalUser(external_id=user_id, display_name=name)
    Action(incident=incident, details=message, user=action_reporter).save()
    return True, None



import json
import re

from response.core.models.incident import Incident
from response.slack.models import HeadlinePost, CommsChannel, UserStats, PinnedMessage

from response.slack.decorators import slack_event, handle_incident_command, handle_keywords


def decode_app_mention(payload):
    """
    Convenience function for dealing with the common pattern for app mention slack events.

    Example: @bot create Something's happened
    Extracts:  slack_id -> "@bot"
               command  -> "create"
               extra    -> "Something's happened"

    @param payload an app mention string of the form @bot create Something's happened
    @return: three variables split by bot, action and extra text
    """
    incident_command_re = re.compile(r"(<@[A-Z0-9]+>)\s+(\w+)\s*(.*)")
    m = incident_command_re.match(payload.strip())

    if not m or len(m.groups()) != 3:
        raise ValueError(
            f'Could not parse app mention payload "{payload}" into "@<bot> <command> <text>"')

    slack_id = m.group(1)
    command = m.group(2)
    extra = m.group(3)

    return slack_id, command, extra


@slack_event('app_mention')
def handle_app_mention(incident: Incident, payload: json):
    """
    Events of type `app_mention` are of the form `@incident some text here`
    We handle all of these as incident_commands
    """
    _, command_name, message = decode_app_mention(payload['text'])

    channel_id = payload['channel']
    user_id = payload['user']
    thread_ts = payload['ts']

    handle_incident_command(command_name, message, thread_ts, channel_id, user_id)


@slack_event('message')
def handle_keyword_detection(incident: Incident, payload: json):
    handle_keywords(payload)


@slack_event('message')
def update_user_stats(incident: Incident, payload: json):
     # message with a user field are messages coming from users.
    if 'user' in payload:
        user_id = payload['user']
        UserStats.increment_message_count(incident, user_id)


@slack_event('pin_added')
def handle_pin_added(incident, payload):
    """
    Handler for pin added events

    @param payload a slack pin_added event
    """
    pinned_message = payload['item']['message']

    if 'user' in pinned_message:
        author_id = pinned_message['user']
        message_ts = pinned_message['ts']
        text = pinned_message['text']
        PinnedMessage.objects.add_pin(incident, message_ts, author_id, text)


@slack_event('pin_removed')
def handle_pin_removed(incident, payload):
    """
    Handler for pin removed events

    @param payload a slack pin_removed event
    """

    pinned_message = payload['item']['message']
    message_ts = pinned_message['ts']

    PinnedMessage.objects.remove_pin(incident, message_ts)



from rest_framework import serializers
from rest_framework.decorators import action

from response.core.models.incident import Incident
from response.core.models.action import Action
from response.core.models.user_external import ExternalUser

from django.contrib.auth.models import User


class ExternalUserSerializer(serializers.HyperlinkedModelSerializer):
    owner = serializers.PrimaryKeyRelatedField(queryset=User.objects.all(), required=False)

    class Meta:
        model = ExternalUser
        fields = ('app_id', 'external_id', 'owner', 'display_name')


class ActionSerializer(serializers.HyperlinkedModelSerializer):
    # Serializers define the API representation.
    incident = serializers.PrimaryKeyRelatedField(queryset=Incident.objects.all(), required=False)
    user = serializers.PrimaryKeyRelatedField(queryset=ExternalUser.objects.all(), required=False)

    class Meta:
        model = Action
        fields = ('pk', 'details', 'done', 'incident', 'user')


class IncidentSerializer(serializers.HyperlinkedModelSerializer):
    reporter = serializers.PrimaryKeyRelatedField(queryset=ExternalUser.objects.all(), required=False)
    lead = serializers.PrimaryKeyRelatedField(queryset=ExternalUser.objects.all(), required=False)

    class Meta:
        model = Incident
        fields = ('pk','report', 'reporter', 'lead', 'start_time', 'end_time', 'report_time', 'action_set')

    def __init__(self, *args, **kwargs):
        super(IncidentSerializer, self).__init__(*args, **kwargs)
        request = kwargs['context']['request']
        expand = request.GET.get('expand', "").split(',')

        if 'actions' in expand:
            self.fields['action_set'] = ActionSerializer(many=True, read_only=True)



from rest_framework import viewsets

from response.core.models.incident import Incident
from response.core.models.action import Action
from response.core.models.user_external import ExternalUser
from response.core.serializers import ExternalUserSerializer, ActionSerializer, IncidentSerializer

from datetime import datetime
from calendar import monthrange


class ExternalUserViewSet(viewsets.ModelViewSet):
    # ViewSets define the view behavior.
    queryset = ExternalUser.objects.all()
    serializer_class = ExternalUserSerializer


class ActionViewSet(viewsets.ModelViewSet):
    # ViewSets define the view behavior.
    queryset = Action.objects.all()
    serializer_class = ActionSerializer


# Will return the incidents of the current month
# Can pass ?start=2019-05-28&end=2019-06-03 to change range
class IncidentViewSet(viewsets.ModelViewSet):
    # ViewSets define the view behavior.

    serializer_class = IncidentSerializer
    pagination_class = None  # Remove pagination

    def get_queryset(self):
        # Same query is used to get single items so we check if pk is passed
        # incident/2/ if we use the filter below we would have to have correct time range
        if 'pk' in self.kwargs:
            return Incident.objects.filter(pk=self.kwargs['pk'])

        today = datetime.today()
        first_day_of_current_month = datetime(today.year, today.month, 1)
        days_in_month = monthrange(today.year, today.month)[1]
        last_day_of_current_month = datetime(today.year, today.month, days_in_month)

        start = self.request.GET.get('start', first_day_of_current_month)
        end = self.request.GET.get('end', last_day_of_current_month)

        return Incident.objects.filter(start_time__gte=start, start_time__lte=end)



import logging

from django.conf import settings
from django.db import models
from django.urls import reverse
from urllib.parse import urljoin

from response import errors
from response.core.models.incident import Incident
from response.slack.models.comms_channel import CommsChannel

from response.slack.block_kit import *
from response.slack.client import user_reference, channel_reference

logger = logging.getLogger(__name__)

class HeadlinePostManager(models.Manager):
    def create_headline_post(self, incident):
        headline_post = self.create(
            incident=incident,
        )
        headline_post.update_in_slack()
        return headline_post


class HeadlinePost(models.Model):

    EDIT_INCIDENT_BUTTON = "edit-incident-button"
    CLOSE_INCIDENT_BUTTON = "close-incident-button"
    CREATE_COMMS_CHANNEL_BUTTON = "create-comms-channel-button"
    PAGE_ON_CALL_BUTTON = "page-on-call-button"

    objects = HeadlinePostManager()
    incident = models.ForeignKey(Incident, on_delete=models.CASCADE)
    message_ts = models.CharField(max_length=20, null=True)
    comms_channel = models.OneToOneField(CommsChannel, on_delete=models.DO_NOTHING, null=True)

    def update_in_slack(self):
        "Creates/updates the slack headline post with the latest incident info"
        logging.info(f"Updating headline post in Slack for incident {self.incident.pk}")
        msg = Message()

        # Set the fallback text so notifications look nice
        msg.set_fallback_text(f"{self.incident.report} reported by {user_reference(self.incident.reporter)}")

        # Add report/people
        msg.add_block(Section(block_id="report", text=Text(f"*{self.incident.report}*")))
        msg.add_block(Section(block_id="reporter", text=Text(f"🙋🏻‍♂️ Reporter: {user_reference(self.incident.reporter.external_id)}")))
        incident_lead_text = user_reference(self.incident.lead.external_id) if self.incident.lead else "-"
        msg.add_block(Section(block_id="lead", text=Text(f"👩‍🚒 Incident Lead: {incident_lead_text}")))

        msg.add_block(Divider())

        # Add additional info
        msg.add_block(Section(block_id="status", text=Text(f"{self.incident.status_emoji()} Status: {self.incident.status_text().capitalize()}")))
        severity_text = self.incident.severity_text().capitalize() if self.incident.severity_text() else "-"
        msg.add_block(Section(block_id="severity", text=Text(f"{self.incident.severity_emoji()} Severity: {severity_text}")))

        doc_url = urljoin(
            settings.SITE_URL,
            reverse('incident_doc', kwargs={'incident_id': self.incident.pk})
        )
        msg.add_block(Section(block_id="incident_doc", text=Text(f"📄 Document: <{doc_url}|Incident {self.incident.pk}>")))

        channel_ref = channel_reference(self.comms_channel.channel_id) if self.comms_channel else None
        if channel_ref:
            msg.add_block(Section(block_id="comms_channel", text=Text(f"🗣 Comms Channel: {channel_ref or '-'}")))

        # Add buttons (if the incident is open)
        if not self.incident.is_closed():
            msg.add_block(Section(text=Text("Need something else?")))
            actions = Actions(block_id="actions")

            if not self.comms_channel:
                actions.add_element(Button(":speaking_head_in_silhouette: Create Comms Channel", self.CREATE_COMMS_CHANNEL_BUTTON, value=self.incident.pk))

            actions.add_element(Button(":pencil2: Edit", self.EDIT_INCIDENT_BUTTON, value=self.incident.pk))

            actions.add_element(Button(":white_check_mark: Close", self.CLOSE_INCIDENT_BUTTON, value=self.incident.pk))

            msg.add_block(actions)

        # Post / update the slack message
        response = msg.send(settings.INCIDENT_CHANNEL_ID, self.message_ts)
        logging.info(f"Got response back from Slack after updating headline post: {response}")


        # Save the message ts identifier if not already set
        if not self.message_ts:
            self.message_ts = response['ts']
            self.save()



import json
import logging
from datetime import datetime

import after_response

from django.conf import settings
from django.http import HttpResponse, JsonResponse
from django.views.decorators.csrf import csrf_exempt

from response.core.models.incident import Incident
from response.slack.decorators import handle_action, handle_event, handle_notifications, handle_dialog
from response.slack.authentication import slack_authenticate
from response.slack.dialog_builder import Dialog, Text, TextArea, SelectWithOptions, SelectFromUsers
from response.slack.settings import INCIDENT_REPORT_DIALOG
from response.slack.client import channel_reference


logger = logging.getLogger(__name__)


@csrf_exempt
@slack_authenticate
def slash_command(request):
    """
    Handles slash commands from slack
    More details here: https://api.slack.com/slash-commands

    @param request the request from slack containing the slash command
    @return: return a HTTP response to indicate the request was handled
    """

    user_id = request.POST.get('user_id')
    trigger_id = request.POST.get('trigger_id')
    report = request.POST.get('text')

    dialog = Dialog(
        title="Report an Incident",
        submit_label="Report",
        elements=[
            Text(label="Report", name="report", placeholder="What's the tl;dr?", value=report),
            TextArea(label="Summary", name="summary", optional=True, placeholder="Can you share any more details?"),
            TextArea(label="Impact", name="impact", optional=True, placeholder="Who or what might be affected?", hint="Think about affected people, systems, and processes"),
            SelectFromUsers(label="Lead", name="lead", optional=True),
            SelectWithOptions([(s.capitalize(), i) for i, s in Incident.SEVERITIES], label="Severity", name="severity", optional=True)
        ]
    )

    logger.info(f"Handling Slack slash command for user {user_id}, report {report} - opening dialog")

    dialog.send_open_dialog(INCIDENT_REPORT_DIALOG, trigger_id)
    return HttpResponse()


@csrf_exempt
@slack_authenticate
def action(request):
    """
    Handles actions sent from Slack.

    @param request the request from slack containing an action
    @return: return a HTTP response to indicate the request was handled
    """
    payload = json.loads(request.POST['payload'])
    action_type = payload['type']

    logger.info(f"Handling Slack action of type '{action_type}'")

    if action_type == 'dialog_submission':
        handle_dialog.after_response(payload)
    elif action_type == 'block_actions':
        handle_action.after_response(payload)
    else:
        logger.error(f"No handler for action type {action_type}")

    return HttpResponse()


@csrf_exempt
@slack_authenticate
def event(request):
    """
    Handles events sent from Slack.

    Details: We can configure our Slack app receive specific events, and doing so tells
    slack to call this endpoint with a JSON payload representing the event.

    See here for reference: https://api.slack.com/events-api

    @param request the request from slack containing an event
    @return: return a HTTP response to indicate the request was handled
    """
    payload = json.loads(request.body)
    action_type = payload['type']

    logger.info(f"Handling Slack event of type '{action_type}'")

    if action_type == 'event_callback':
        handle_event(payload)
    elif action_type == 'url_verification':
        # the url_verification event is called when we change the registered event callback url
        # in the Sl ack app configuration.  It expects us to return the challenge token sent in
        # the request
        return HttpResponse(payload['challenge'])

    return HttpResponse()


@csrf_exempt
def cron_minute(request):
    "Handles actions that need to take place every minute"
    handle_notifications()
    return HttpResponse()



# Generated by Django 2.2.3 on 2019-07-19 10:27

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='CommsChannel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('channel_id', models.CharField(max_length=20)),
            ],
        ),
        migrations.CreateModel(
            name='ExternalUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('app_id', models.CharField(max_length=50)),
                ('external_id', models.CharField(max_length=50)),
                ('display_name', models.CharField(max_length=50)),
                ('owner', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'unique_together': {('owner', 'app_id')},
            },
        ),
        migrations.CreateModel(
            name='Incident',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('report', models.CharField(max_length=200)),
                ('report_time', models.DateTimeField()),
                ('start_time', models.DateTimeField()),
                ('end_time', models.DateTimeField(blank=True, null=True)),
                ('summary', models.TextField(blank=True, help_text="What's the high level summary?", null=True)),
                ('impact', models.TextField(blank=True, help_text='What impact is this having?', null=True)),
                ('severity', models.CharField(blank=True, choices=[('1', 'critical'), ('2', 'major'), ('3', 'minor'), ('4', 'trivial')], max_length=10, null=True)),
                ('lead', models.ForeignKey(blank=True, help_text='Who is leading?', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='lead', to='response.ExternalUser')),
                ('reporter', models.ForeignKey(null=True, on_delete=django.db.models.deletion.PROTECT, related_name='reporter', to='response.ExternalUser')),
            ],
        ),
        migrations.CreateModel(
            name='PinnedMessage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('message_ts', models.CharField(max_length=50)),
                ('text', models.TextField()),
                ('timestamp', models.DateTimeField()),
                ('author', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='response.ExternalUser')),
                ('incident', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='response.Incident')),
            ],
        ),
        migrations.CreateModel(
            name='HeadlinePost',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('message_ts', models.CharField(max_length=20, null=True)),
                ('comms_channel', models.OneToOneField(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='response.CommsChannel')),
                ('incident', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='response.Incident')),
            ],
        ),
        migrations.AddField(
            model_name='commschannel',
            name='incident',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='response.Incident'),
        ),
        migrations.CreateModel(
            name='Action',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('details', models.TextField(blank=True, default='')),
                ('done', models.BooleanField(default=False)),
                ('incident', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='response.Incident')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='response.ExternalUser')),
            ],
        ),
        migrations.CreateModel(
            name='UserStats',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('join_time', models.DateTimeField(null=True)),
                ('message_count', models.IntegerField(default=0)),
                ('incident', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='response.Incident')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='response.ExternalUser')),
            ],
            options={
                'unique_together': {('incident', 'user')},
            },
        ),
        migrations.CreateModel(
            name='Notification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=30)),
                ('time', models.DateTimeField()),
                ('repeat_count', models.IntegerField(default=0)),
                ('completed', models.BooleanField(default=False)),
                ('incident', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='response.Incident')),
            ],
            options={
                'unique_together': {('incident', 'key')},
            },
        ),
        migrations.CreateModel(
            name='IncidentExtension',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=50)),
                ('value', models.CharField(max_length=100)),
                ('incident', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='response.Incident')),
            ],
            options={
                'unique_together': {('incident', 'key')},
            },
        ),
    ]



import os
from setuptools import find_packages, setup

VERSION = '0.0.2'

INSTALL_REQUIRES = [
    'Django>=2.2',
    'bleach==3.1.0',
    'cryptography>=2.7',
    'django-after-response>=0.2.2',
    'django-bootstrap4>=0.0.7',
    'djangorestframework>=3.9.2',
    'emoji-data-python==1.1.0',
    'markdown2>=2.3.7',
    'python-slugify>=1.2.6',
    'slackclient>=1.3,<2',
    'statuspageio>=0.0.1',
]

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

# load README.md
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(
    name='django-incident-response',
    version=VERSION,
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=find_packages(exclude="demo"),
    install_requires=INSTALL_REQUIRES,
    package_dir={"response": "response"},
    python_requires='>3.6',
    include_package_data=True,
    license='MIT License',  # example license
    description='A real-time incident response and reporting tool',
    url='https://github.com/monzo/response',
    author='Chris Evans',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 2.2',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
